

// Mortar Fire Mission script 
// Executes Fire Mission 
// 0 = [MortarGroup, "HE", 4, position] execVM "MortarFire.sqf"

private ["_group", "_roundType", "_numRounds", "_template", "_pos", "_veh", "_var", "_marker", "_firedEH"];

// INPUT VARIABLES
_group = _this select 0; // the group in question
_roundType = _this select 1; // string round type 
_numRounds = _this select 2; // number of rounds
_pos = _this select 3; // actual position
_veh = vehicle (leader _group); // default value for the vehicle
_var = _group getVariable "DZ_WTS_Type"; // get data from object variable space

// exit script checks
if (!(_group getVariable "DZ_WTS_Deployed")) exitWith {hint "Weapon Team Not Yet Deployed."}; // exit if the team is not deployed
if ((_group getVariable "DZ_WTS_Type") != 0) exitWith {hint "No Mortar Team Selected!"}; // exit if no mortar teams were selected
if ((_group getVariable "DZ_WTS_Ammo") < 1) exitWIth {hint format ["%1 is out of ammo for fire mission!", _group];}; // exit if the mortar team has no ammo left
if (isNil "_var") exitWIth {}; // exit if the group is not even defined in script

// find vehicle 
{
    if (vehicle _x != _x) then {
        _veh = vehicle _x;	
    };
} foreach (units _group);

private ["_LogicCenter", "_moduleGroup", "_ARTYMODULE"];
// create Module
_LogicCenter = createCenter sideLogic;
_moduleGroup = createGroup _LogicCenter;
_ARTYMODULE = _moduleGroup createUnit  ["BIS_ARTY_Logic", [0,0,0], [], 0, "NONE"]; 
_ARTYMODULE synchronizeObjectsAdd [_veh];

// Initialize fire mission template and vehicle
_template = ["IMMEDIATE", _roundType, 0, _numRounds];
[_veh] call BIS_ARTY_F_initVehicle;

_pos set [2, getTerrainHeightASL _pos];

// createMarker
_marker = createMarker [ ( format ["DZ_WTS_Mark_%1", round (random 100)] ), _pos];
_marker setMarkerType "Destroy";

//waitUntil {_ARTYMODULE getVariable "BIS_ARTY_LOADED"};

sleep 2;

// call function to see if position is in range of mortar teams
if ([_ARTYMODULE, _pos, _template select 1] call BIS_ARTY_F_PosInRange) then {
    
    // add fired event handler, remove ammo count for each fired shell
    _firedEH = _veh addEventHandler ["Fired", {
        private ["_grp", "_ammoCount"];
        _grp = group (gunner (_this select 0)); // the group veh belongs to
        _ammoCount = _grp getVariable "DZ_WTS_Ammo"; // shell count 
        _ammoCount = _ammoCount - 1; // subtract
        _grp setVariable ["DZ_WTS_Ammo", _ammoCount];
        //hint format ["Shells Left: %1", _ammoCount];
    }]; 
    
    [_ARTYMODULE, _pos, _template] call BIS_ARTY_F_ExecuteTemplateMission; // execute fire mission
    (leader _group) sidechat format ["%1 Executing Fire Mission", _group];
} else {
    (leader _group) sidechat format ["%1 Here, cannot execute fire mission, target is out of range.", _group];
};

sleep 4;

// waitUntil the mortar has finished firing, or has cancelled fire mission
waitUntil {
	private ["_cancel", "_ammo"];
	_cancel = _group getVariable "DZ_WTS_Cancel"; // get cancel status
    _ammo = _group getVariable "DZ_WTS_Ammo"; // get ammo status
	if (_cancel || _ammo < 1) then {
		_ARTYMODULE setVariable ["ARTY_CANCEL", true]; // cancel fire mission
	};
	([_ARTYMODULE, _pos, _template select 1] call BIS_ARTY_F_Available) || (_ARTYMODULE getVariable "ARTY_CANCEL")
};

// dialog for finishing fire mission
if (!(_ARTYMODULE getVariable "ARTY_CANCEL") && (_group getVariable "DZ_WTS_Ammo") > 0) then {
    (leader _group) sidechat format ["%1 Rounds Complete", _group];
};

// dialog for cancelling fire mission
if ((_ARTYMODULE getVariable "ARTY_CANCEL")) then {
    (leader _group) sidechat format ["%1 Cancelling Fire Mission", _group];
};

// dialog for no more ammo for fire mission 
if ((_group getVariable "DZ_WTS_Ammo") < 1) then {
    (leader _group) sidechat format ["%1 has run out of ammo for fire mission", _group];
};

_veh removeEventHandler ["Fired", _firedEH]; // remove event handler
_group setVariable ["DZ_WTS_Cancel", false]; // set cancel back to default status

// delete marker, arty logic, and group
deletemarker _marker;
deleteVehicle _ARTYMODULE;
deleteGroup _moduleGroup;




