
// High Command Weapon Script
// Created by Igneous01
// Version 1.0
// changes:
// - added ammo count for MG teams
// - added OA backpacks for all weapon teams
// - added support for multiple selections for weapon team actions
// - added ammo count for mortar teams
// - added mortar fire mission submenu
// - added more fire mission types in sub menu


// Weapon Team Initialization Script
// nul = [[group1, group2], [group3, group4]] execVM "WeaponInit.sqf"
// where first array is for Mortar Teams, Second is for MG teams
// use the communication menu (0-8) to see some actions for weapon teams 

// inputs
private ["_MortarGroups", "_MGGroups"];
_MortarGroups = _this select 0;
_MGGroups = _this select 1;


if (count _MortarGroups > 0) then {
    { 
        _x setvariable ["MARTA_customIcon",["o_mortar"]]; // High command group icon
        _x setVariable ["DZ_WTS_Type", 0]; // type is either 0 (mortar) or 1 (mg)
        _x setVariable ["DZ_WTS_Deployed", false]; // variable that checks to see if group is deployed or not
        _x setVariable ["DZ_WTS_Cancel", false]; // used to cancel fire mission for mortars
        _x setVariable ["DZ_WTS_Ammo", 12]; // initial number of shells available for the mortar team
        _x enableAttack false;
        
        // Getting weapon and backpack for each side
        if (side _x == EAST) then {
            _x setVariable ["DZ_WTS_Weapon", "2b14_82mm"];
			_x setVariable ["DZ_WTS_Backpacks", ["Tripod_Bag", "2b14_82mm_TK_Bag_EP1"]];
        };
        if (side _x == WEST) then {
            _x setVariable ["DZ_WTS_Weapon", "M252"];
			_x setVariable ["DZ_WTS_Backpacks", ["Tripod_Bag", "M252_US_Bag_EP1"]];
        };
        if (side _x == RESISTANCE) then {
            _x setVariable ["DZ_WTS_Weapon", "2b14_82mm_GUE"];
			_x setVariable ["DZ_WTS_Backpacks", ["Tripod_Bag", "2b14_82mm_TK_Bag_EP1"]];
        };   
    } foreach _MortarGroups;
};

if (count _MGGroups > 0) then {  
    {
        _x setvariable ["MARTA_customIcon",["o_support"]]; // High command group icon
        _x setVariable ["DZ_WTS_Type", 1]; // type 1 (MG)
        _x setVariable ["DZ_WTS_Deployed", false]; // checks whether the team is deployed or not
        _x setVariable ["DZ_WTS_Ammo", 6]; // initial amount of belts for mg
        _x enableAttack false;
        
        // getting weapon for each side
        if (side _x == EAST) then {
            _x setVariable ["DZ_WTS_Weapon", "DSHKM_Ins"];
			_x setVariable ["DZ_WTS_Backpacks", ["Tripod_Bag", "DSHKM_TK_GUE_Bag_EP1"]];
        };
        if (side _x == WEST) then {
            _x setVariable ["DZ_WTS_Weapon", "M2StaticMG"];
			_x setVariable ["DZ_WTS_Backpacks", ["Tripod_Bag", "M2StaticMG_US_Bag_EP1"]];
        };
        if (side _x == RESISTANCE) then {
            _x setVariable ["DZ_WTS_Weapon", "DSHKM_Gue"];
			_x setVariable ["DZ_WTS_Backpacks", ["Tripod_Bag", "DSHKM_TK_GUE_Bag_EP1"]];
        };     
    } foreach _MGGroups;
};


// create initial communication menu
waituntil {!isnil "bis_fnc_init"};
[] call BIS_fnc_commsMenuCreate;


// String variables containing code for comm menu
// this simplifies editing the comm menu
private ["_4rndHEString", "_8rndHEString", "_4rndWPString", "_8rndWPString", "_4rndILLString", "_8rndILLString", "_initString"];


// a simple function to reduce amount of code needed in comm menu mortar fire missions
// returns formatted string
_initString = {
    private ["_param1", "_param2", "_string"];
    _param1 = _this select 0;
    _param2 = _this select 1;
    _string = format ["hint 'Select coordinates on map'; WTS_GROUPS = hcSelected player; onMapSingleClick {onMapSingleClick {}; {0 = [_x, %1, %2, _pos] execVM 'WeaponTeamScript\MortarFire.sqf'} foreach WTS_GROUPS};", str _param1, _param2];
    _string
};

// create code strings for comm menu
_4rndHEString = ["HE", 4] call _initString;
_8rndHEString = ["HE", 8] call _initString;
_4rndWPString = ["WP", 4] call _initString;
_8rndWPString = ["WP", 8] call _initString;
_4rndILLString = ["ILLUM", 4] call _initString;
_8rndILLString = ["ILLUM", 8] call _initString;


// Mortar Fire Mission Submenu
WeaponTeam_MortarFire_SUBMENU = [
    ["Mortar Fire Mission",false],
    ["4 Round HE", [2], "", -5, [["expression",  _4rndHEString]], "1", "1"],
    ["8 Round HE", [3], "", -5, [["expression", _8rndHEString]], "1", "1"],
    ["4 Round WP", [4], "", -5, [["expression", _4rndWPString]], "1", "1"],
    ["8 Round WP", [5], "", -5, [["expression", _8rndWPString]], "1", "1"],
    ["4 Round ILLUM", [6], "", -5, [["expression", _4rndILLString]], "1", "1"],
    ["8 Round ILLUM", [7], "", -5, [["expression", _8rndILLString]], "1", "1"],
    ["Cancel Mission", [8], "", -5, [["expression", "{_x setVariable [""DZ_WTS_Cancel"", true]} foreach (hcSelected player)"]], "1", "1"]
];
    
// Main Menu of weapon team
WeaponTeam_MAINMENU = 
[	
    ["Weapon Team Menu",false],
    ["Deploy Weapon", [2], "", -5, [["expression", "{0 = [_x, _x getVariable ""DZ_WTS_Weapon""] execVM ""WeaponTeamScript\DeployWeapon.sqf""} foreach hcSelected player"]], "1", "1"],
    ["Pack Up Weapon", [3], "", -5, [["expression", "{0 = [_x] execVM ""WeaponTeamScript\packup.sqf""} foreach hcSelected player"]], "1", "1"],
    ["Order Fire Mission (Mortar)", [4], "#USER:WeaponTeam_MortarFire_SUBMENU", -5, [["expression", ""]], "1", "1"],
    ["Suppressive Fire (MG)", [5], "", -5, [["expression", "{_x suppressFor 60} foreach units ((hcSelected player) select 0)"]], "1", "1"]
];


// waits until the comms menu has finished initializing
waituntil {!isnil "BIS_MENU_GroupCommunication"};
[BIS_MENU_GroupCommunication, ["Weapon Team Menu",[0],"#USER:WeaponTeam_MAINMENU",-5,[["expression",""]],"1","0"]] call BIS_fnc_arrayPush;


// Spawn function for making group go into weapon if gunner is killed
DZ_WTS_TakeOver = {
	private ["_group", "_weap"];
	_group = _this select 0;
	{
		if (vehicle _x != _x) then {
			_weap = vehicle _x; // the actual weapon belonging to the team when its deployed
		};
	} foreach units _group;
    
    // this loop continues until the team is no longer deployed (ordered to pack up) or all group members are dead
	while {(_group getVariable "DZ_WTS_Deployed")} do {
		if (!alive (gunner _weap)) then {
            private ["_next"];
			_next = (units _group) select (floor(random(count (units _group)))); // select a random unit alive in the group 
			_next assignasGunner _weap;
			[_next] ordergetIn true;
		};
		if (count (units _group) < 1) exitWith {}; // if group dies, cancel script
		sleep 4;
	};
};

// function to add backpacks to units
// _group call DZ_WTS_BACKPACK_ADD
DZ_WTS_BACKPACK_ADD = {
	private ["_group", "_units", "_backpacks", "_bag", "_count"];
	_group = _this;
	_units = units _group;
	_backpacks = _group getVariable "DZ_WTS_Backpacks";
	_count = 0;
	{
		_bag = _backpacks select _count;
		_x addBackpack _bag;
		_count = _count + 1;
		if (_count > 1) then {
			_count = 0;
		};
	} foreach _units;
};

{_x call DZ_WTS_BACKPACK_ADD} foreach _MortarGroups + _MGGroups; // add backpacks to groups

// Loop to see if any of these groups have been selected in high command, addActions for these groups
while {true} do {
    private ["_groups"];
    _groups = hcSelected player;
    //hint format ["groups: %1", _groups];
    
    // enable comm menu when some groups in hc are selected 
    if ((count _groups) > 0) then {
        {
	         BIS_MENU_GroupCommunication set [(count BIS_MENU_GroupCommunication) - 1, ["Weapon Team Menu",[0],"#USER:WeaponTeam_MAINMENU",-5,[["expression",""]],"1","1"]];                   
        } foreach _groups;
    };
    
    waitUntil {_groups = hcSelected player; (count _groups) < 1}; // waits until no groups are selected in high command, locks comm menu
    BIS_MENU_GroupCommunication set [(count BIS_MENU_GroupCommunication) - 1, ["Weapon Team Menu",[0],"#USER:WeaponTeam_MAINMENU",-5,[["expression",""]],"1","0"]];                   
    sleep 0.5;
};



